/*
History: 
   kk05Nov04 +RedirectToVersionURL
   kk19Nov04 Changed the version URL format to be a fixed number of chars to simplify server processing.
   kk20Dec04 Changed to detect host-side execution and do nothing. Also fixed it so it works
             when the version in the URL is not the current version.
   kk25Jan05 Changed app to use SMU URL.
   kk26Apr05 Modified version number to use BUILD_NUMBER instead of internal/external pass.
   kk27Apr05 Made a fix to guarantee the "/" char exists after the version encoding in
             the URL. Certain versions of IE appear to leave it off.
   kk20Sep05 Added leading zeroes to version numbers when necessary.
   jt18Dec06 Changed back to use ACU-XE URL
*/

//CVersion
//  Class to get the application version
//
//public methods:
//  toString()
//     returns the current application version as a string
//  RedirectToVersionURL()
//     redirects the application to a URL based on the current version
//     if already not using a URL based on the current version.
//     This  is used to prevent browser caching from messing up application 
//     upgrades. Returns true if the redirect will occur. Returns false otherwise.
//
function CVersion()
{
   var DOT = ".";
   var ZERO = "0";
   var m_versionString = "" + MAJOR_VERSION + DOT;
   if (MINOR_VERSION < 10)
   {
      m_versionString += ZERO;
   }
   m_versionString += MINOR_VERSION + DOT;
   if (BUILD_NUMBER < 10)
   {
      m_versionString += ZERO;
   }
   m_versionString += BUILD_NUMBER;

   
   this.toString = function()
   {
      return m_versionString;
   }
   
   this.RedirectToVersionURL = function()
   {
      var isRedirect = false;
      var urlString = "" + document.location;
      
      //Test to see if we are running on host side.
      //If so, do no redirection.
      var hostSideRegExp = new RegExp("/(A|a)(C|c)(U|u)-(X|x)(E|e)/");
      if (!hostSideRegExp.test(urlString))
      {
         //We are not running on host side.
         //Test to see if there is a version marker in the URL
         var newUrl = "";
         var versionRegExp = new RegExp("/v[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]/");
         var ar = versionRegExp.exec(urlString);
         if (ar != null)
         {
            //There is a version marker in the URL.
            //Test to see if the version marker matches the current version.
            //If it does, do nothing - the URL is fine.
            //If it does not match, then replace it with the current version.
            var thisVersionRegExp = new RegExp("/"  + versionUrlEncoding() + "/");
            if (!thisVersionRegExp.test(urlString))
            {
               //The new URL will have the /v########/ in it with the current version
               var urlStart = urlString.substr(0,ar.index + 1);
               var urlEnd = urlString.substr(ar.index + 10);
               if (urlEnd.charAt(0) != "/")
               {
                  urlEnd = "/" + urlEnd;
               }
               newUrl = urlStart + versionUrlEncoding() + urlEnd;
               isRedirect=true;
            }
         }
         else
         {
            //There is no version marker in the URL. Put one in there.
            //The new URL will have the /v########/ in it with the current version
            var lastSlashIndex = urlString.lastIndexOf("/");
            var urlStart = urlString.substr(0,lastSlashIndex + 1);
            var urlEnd = urlString.substr(lastSlashIndex);
            if (urlEnd.charAt(0) != "/")
            {
               urlEnd = "/" + urlEnd;
            }
            newUrl = urlStart + versionUrlEncoding() + urlEnd;
            isRedirect = true;
         }
         
         if (isRedirect)
         {
            document.location = newUrl;
         }
      }
      
      return isRedirect;
   }
   
   function versionUrlEncoding()
   {
      var str = "v" + NumToStr(MAJOR_VERSION, 2) + NumToStr(MINOR_VERSION, 2) + NumToStr(BUILD_NUMBER, 4);
      return str;
   }
   
   //NumToStr
   //converts number to string with leading zeros if necessary.
   //fieldWidth is optional and specifies the width of the number
   //If the number as a string is smaller than the field width,
   //leading zeros are inserted.
   function NumToStr(num, fieldWidth)
   {
      var numStr = "" + num;
      if (typeof(fieldWidth) != "undefined")
      {
         var numZeros = fieldWidth - numStr.length;
         for (var i=0; i < numZeros; ++i)
         {
            numStr = "0" + numStr;
         }
      }
      
      return numStr;
   }
}
